function res = test_asin
% test_asin - unit_test_function of sine for intervals - Overloaded 'asin()' function for intervals
%
% Syntax:  
%    res = test_asin
%
% Inputs:
%    no
%
% Outputs:
%    res - boolean 
%
% Example: 
%
% Other m-files required: none
% Subfunctions: none
% MAT-files required: none
%
% See also: mtimes

% Author:       Mark Wetzlinger
% Written:      08-August-2020
% Last update:  ---
% Last revision:---

%------------- BEGIN CODE --------------

tol = 1e-9;
res = true;

% 1. Check special values -------------------------------------------------

% x     asin(x)
% -1    -pi/2
% 0     0
% 1     pi/2

a = interval([-1,0],[1,0]);
b = asin(a);

binf_true = [-pi/2,0];
bsup_true = [pi/2,0];

res_val = true;
if any(abs( b.inf - binf_true ) > tol) || any(abs( b.sup - bsup_true ) > tol)
    res_val = false;
end


% 2. random tests ---------------------------------------------------------

numberRandTests = 10000;

% all x<1 or x>1 must return NaN
res_rand(1) = true;
for i=1:numberRandTests
    a = interval(-1-randi(1000,1,1)*rand(1),1+randi(1000,1,1)*rand(1));
    try
        b = asin(a); % error should be thrown here
        % in case no error is thrown, all should be NaN
        if ~all(isnan(b.inf)) || ~all(isnan(b.sup))
            res_rand(1) = false;
            break
        end
    catch
        continue;
    end
end

% all x>=-1 and x<=1 map to somewhere in [-pi/2,pi/2]
res_rand(2) = true;
for i=1:numberRandTests
    a = interval(-rand(1),rand(1));
    b = asin(a);
    if b.inf < -pi/2 || b.sup > pi/2
        res_rand(2) = false;
        break
    end
end



% final test result -------------------------------------------------------

res = all(res_val) && all(res_rand);

if res
    disp('test_asin successful');
else
    disp('test_asin failed');
end

end

%------------- END OF CODE --------------